@@ -11,7 +11,7 @@ use Exporter qw(import);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-15'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.012'; # VERSION
+our $VERSION = '1.013'; # VERSION
 
 our @EXPORT_OK = qw(
                        gen_csv_util
@@ -1002,6 +1002,12 @@ The order of the hooks, in processing chronological order:
   row will be the generated `["field1", "field2", ...]`. You can use this hook
   e.g. to add/remove/rearrange fields.
 
+  You can set `$r->{wants_fill_rows}` to a defined false if you do not want
+  `$r->{input_rows}` to be filled with empty string elements when it contains
+  less than the number of fields (in case of sparse values at the end). Normally
+  you only want to do this when you want to do checking, e.g. in
+  <prog:csv-check-rows>.
+
 * on_input_data_row
 
   Called when receiving each data row. You can use this hook e.g. to modify the
@@ -1635,8 +1641,10 @@ sub gen_csv_util {
                             } else {
                                 # fill up the elements of row to the number of
                                 # fields, in case the row contains sparse values
-                                if (@{ $r->{input_row} } < @{ $r->{input_fields} }) {
-                                    splice @{ $r->{input_row} }, scalar(@{ $r->{input_row} }), 0, (("") x (@{ $r->{input_fields} } - @{ $r->{input_row} }));
+                                unless (defined $r->{wants_fill_rows} && !$r->{wants_fill_rows}) {
+                                    if (@{ $r->{input_row} } < @{ $r->{input_fields} }) {
+                                        splice @{ $r->{input_row} }, scalar(@{ $r->{input_row} }), 0, (("") x (@{ $r->{input_fields} } - @{ $r->{input_row} }));
+                                    }
                                 }
 
                                 # generate the hashref version of row if utility
@@ -1866,7 +1874,7 @@ App::CSVUtils - CLI utilities related to CSV
 
 =head1 VERSION
 
-This document describes version 1.012 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-15.
+This document describes version 1.013 of App::CSVUtils (from Perl distribution App-CSVUtils), released on 2023-02-15.
 
 =head1 DESCRIPTION
 
@@ -1884,6 +1892,8 @@ This distribution contains the following CLI utilities:
 
 =item * L<csv-check-field-values>
 
+=item * L<csv-check-rows>
+
 =item * L<csv-concat>
 
 =item * L<csv-convert-to-hash>
@@ -2046,6 +2056,12 @@ called even when user specify C<--no-input-header>, in which case the header
 row will be the generated C<["field1", "field2", ...]>. You can use this hook
 e.g. to add/remove/rearrange fields.
 
+You can set C<< $r-E<gt>{wants_fill_rows} >> to a defined false if you do not want
+C<< $r-E<gt>{input_rows} >> to be filled with empty string elements when it contains
+less than the number of fields (in case of sparse values at the end). Normally
+you only want to do this when you want to do checking, e.g. in
+L<csv-check-rows>.
+
 =item * on_input_data_row
 
 Called when receiving each data row. You can use this hook e.g. to modify the
