@@ -7,7 +7,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-02-15'; # DATE
 our $DIST = 'App-CSVUtils'; # DIST
-our $VERSION = '1.012'; # VERSION
+our $VERSION = '1.013'; # VERSION
 
 use App::CSVUtils qw(
                         gen_csv_util
@@ -20,8 +20,9 @@ gen_csv_util(
 
 This utility performs the following checks:
 
-- There is no duplicate field name
-- There is no field name of '' (empty string)
+- There is at least 1 field;
+- There is no duplicate field name;
+- There is no field name of '' (empty string);
 
 There will be options to add some additional checks in the future.
 
@@ -42,6 +43,8 @@ _
     on_input_header_row => sub {
         my $r = shift;
 
+        die [400, "There must at least be 1 field"] unless @{ $r->{input_fields} };
+
         my %seen;
         my $i = 0;
         for my $field (@{ $r->{input_fields} }) {
@@ -72,7 +75,7 @@ App::CSVUtils::csv_check_field_names - Check field names
 
 =head1 VERSION
 
-This document describes version 1.012 of App::CSVUtils::csv_check_field_names (from Perl distribution App-CSVUtils), released on 2023-02-15.
+This document describes version 1.013 of App::CSVUtils::csv_check_field_names (from Perl distribution App-CSVUtils), released on 2023-02-15.
 
 =head1 FUNCTIONS
 
@@ -99,9 +102,11 @@ This utility performs the following checks:
 
 =over
 
-=item * There is no duplicate field name
+=item * There is at least 1 field;
 
-=item * There is no field name of '' (empty string)
+=item * There is no duplicate field name;
+
+=item * There is no field name of '' (empty string);
 
 =back
 
